=======
History
=======

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog <https://keepachangelog.com/en/1.1.0/>`_,
and this project adheres to `Semantic Versioning <https://semver.org/spec/v2.0.0.html>`_.

0.2.0 (Unreleased)
------------------

This release marks as the first to be published to PyPI.

No new functionality was added. The version was changed was to place a history mark.

- Added documentation.
- Added full coverage tests.
- Code refactoring.

0.1.1 (2018-10-16)
------------------

- Better console output.
- Added option ``--revoke-only``.
- Don't reauthorize if the IP address is already in the security group.
- Authorizing and revoking in batch to be more efficient.
- Bugfixes

0.1.0 (2018-09-27)
------------------

- Added option ``--my-ip`` to inform an IP address explicitly.
- Show in console the security groups being processed.
- Allow use as script by reading JSON as external config.
